==> pdf-model-arlington-1.23.7-sources.jar: org/verapdf/model/alayer/AAuthCode.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
public interface AAuthCode extends AObject {
	



	public Boolean getcontainsByteRange();

	public Boolean getisByteRangeIndirect();

	public Boolean getByteRangeHasTypeArray();

	public Boolean getcontainsMAC();

	public Boolean getisMACIndirect();

	public Boolean getMACHasTypeStringByte();

	public Boolean getcontainsMACLocation();

	public Boolean getisMACLocationIndirect();

	public Boolean getMACLocationHasTypeName();

	public String getMACLocationNameValue();

	public Boolean getcontainsSigObjRef();

	public Boolean getisSigObjRefIndirect();

	public Boolean getSigObjRefHasTypeDictionary();

	public Long getByteRange1IntegerValue();

	public Long getByteRange2IntegerValue();

	public Long getByteRange0IntegerValue();

	public Long getByteRange3IntegerValue();
}

==> pdf-model-arlington-1.25.17-sources.jar: org/verapdf/model/alayer/AAuthCode.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AAuthCode extends AObject {
	



	/**
	*/
	public Boolean getcontainsByteRange();

	/**
	*/
	public Boolean getisByteRangeIndirect();

	/**
	*/
	public Boolean getByteRangeHasTypeArray();

	/**
	*/
	public Boolean getcontainsMAC();

	/**
	*/
	public Boolean getisMACIndirect();

	/**
	*/
	public Boolean getMACHasTypeStringByte();

	/**
	*/
	public Boolean getcontainsMACLocation();

	/**
	*/
	public Boolean getisMACLocationIndirect();

	/**
	*/
	public Boolean getMACLocationHasTypeName();

	/**
	*/
	public String getMACLocationNameValue();

	/**
	*/
	public Boolean getcontainsSigObjRef();

	/**
	*/
	public Boolean getisSigObjRefIndirect();

	/**
	*/
	public Boolean getSigObjRefHasTypeDictionary();

	/**
	*/
	public Long getByteRange1IntegerValue();

	/**
	*/
	public Long getByteRange2IntegerValue();

	/**
	*/
	public Long getByteRange0IntegerValue();

	/**
	*/
	public Long getByteRange3IntegerValue();

	/**
	*/
	public Boolean getByteRange1HasTypeInteger();

	/**
	*/
	public Boolean getByteRange2HasTypeInteger();

	/**
	*/
	public Boolean getByteRange0HasTypeInteger();

	/**
	*/
	public Boolean getByteRange3HasTypeInteger();

	/**
	*/
	public Boolean gethasExtensionISO_TS_32004();
}
